Installation
============

From PyPI:

.. code-block:: bash

    pip install amgd

From source:

.. code-block:: bash

    git clone https://github.com/elbakari01/amgd.git 
    cd amgd
    pip install -e .